@@ -15,10 +15,11 @@ import json
 import warnings
 
 from django.db.models import fields as dj_fields
+from django.core import exceptions as dj_exceptions
 from django.utils.encoding import force_unicode
 
 from m3 import actions as m3_actions
-from m3.actions.interfaces import ISelectablePack
+from m3.actions.interfaces import ISelectablePack, IMultiSelectablePack
 from m3 import RelatedError, ApplicationLogicException
 from m3.db import safe_delete
 from m3_ext.ui.fields.complex import ExtSearchField
@@ -67,6 +68,7 @@ class BaseAction(m3_actions.Action):
 
     def get_perm_code(self, subpermission=None):
         """
+        Возвращает код права
 
         :param subpermission: Код подправа доступа
         :type subpermission: str
@@ -275,6 +277,13 @@ class ObjectSelectWindowAction(ObjectListWindowAction):
             self.parent.column_name_on_select)
 
 
+class ObjectMultiSelectWindowAction(ObjectSelectWindowAction):
+    """
+    Базовый Action показа окна списка выбора нескольких объектов из списка
+    """
+    def create_window(self):
+        self.win = self.parent.multi_select_window()
+
 #==============================================================================
 # ObjectEditWindowAction
 #==============================================================================
@@ -551,7 +560,10 @@ class ObjectRowsAction(BaseAction):
             col, subcol = (col.split('.', 1) + [None])[:2]
             # ------- если есть подиндекс - идем вглубь
             if subcol:
-                obj = getattr(obj, col, None)
+                try:
+                    obj = getattr(obj, col, None)
+                except dj_exceptions.ObjectDoesNotExist:
+                    obj = None
                 sub_dict = result.setdefault(col, {})
                 parse_data_indexes(obj, subcol, sub_dict)
             else:
@@ -564,12 +576,17 @@ class ObjectRowsAction(BaseAction):
                 ):
                     fld = None
                 # получаем значение
-                obj = getattr(obj, col, None)
+                try:
+                    obj = getattr(obj, col, None)
+                except dj_exceptions.ObjectDoesNotExist:
+                    obj = None
                 if fld:
                     try:
                         obj = obj.display()
                     except AttributeError:
-                        if fld.choices:
+                        # аттрибут choises существует у Field
+                        # но отсутствует у RelatedObject
+                        if hasattr(fld, 'choices') and fld.choices:
                             # если получаемый атрибут - поле, имеющее choices
                             # пробуем найти соответствующий значению вариант
                             for ch in fld.choices:
@@ -809,7 +826,7 @@ class BasePack(m3_actions.ActionPack):
 #==============================================================================
 # ObjectPack
 #==============================================================================
-class ObjectPack(BasePack, ISelectablePack):
+class ObjectPack(BasePack, IMultiSelectablePack):
     """
     Пак с экшенам, реализующими специфичную для работы с моделью действиями по
     добавлению, редактированию, удалению (CRUD actions)
@@ -1048,11 +1065,17 @@ class ObjectPack(BasePack, ISelectablePack):
     Класс отвечающий за отображение окна со списком объектов
     """
 
-    select_window = ui.BaseSelectWindow  # Форма выбора @UndefinedVariable
+    select_window = ui.BaseSelectWindow  # Форма выбора
     """
     Класс отвечающий за отображение окна выбора из списка объектов
     """
 
+    multi_select_window = ui.BaseMultiSelectWindow  # Форма выбора
+    """
+    Класс отвечающий за отображение окна множественного выбора
+    из списка объектов
+    """
+
     width, height = 600, 400
     """
     Размеры окна по умолчанию
@@ -1104,11 +1127,14 @@ class ObjectPack(BasePack, ISelectablePack):
         #: Экшен показа окна со списком для выбора объектов
         self.select_window_action = ObjectSelectWindowAction()
         #: Экшен с получения данных объектов / редактирование строк
+        self.multi_select_window_action = ObjectMultiSelectWindowAction()
+        #: Экшен с получения данных объектов / редактирование строк
         self.rows_action = ObjectRowsAction()
         # Но привязать их все равно нужно
         self.actions.extend([
             self.list_window_action,
             self.select_window_action,
+            self.multi_select_window_action,
             self.rows_action
         ])
         if self.add_window and not self.read_only:
@@ -1356,6 +1382,18 @@ class ObjectPack(BasePack, ISelectablePack):
         """
         return self.select_window_action.get_absolute_url()
 
+    def get_multi_select_url(self):
+        """
+        Возвращает адрес формы выбора из списка элементов справочника.
+
+        .. note::
+            Используется для присвоения адресов в прикладном приложении
+
+        :return: url экшена показа окна выбора из списка объектов
+        :rtype: str
+        """
+        return self.multi_select_window_action.get_absolute_url()
+
     def get_edit_url(self):
         """
         Возвращает адрес формы редактирования элемента справочника
@@ -1385,6 +1423,10 @@ class ObjectPack(BasePack, ISelectablePack):
         """
         return self.get_rows_url()
 
+    def get_display_dict(self, key, value_field='id', display_field='name'):
+        print key, value_field, display_field
+        return []
+
     def get_not_found_exception(self):
         """
         Возвращает класс исключения 'объект не найден'
